"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var model_1 = require("./model");
var Repository = /** @class */ (function () {
    function Repository(repo) {
        this.repo = repo;
    }
    Repository.prototype.getCategory = function (key) {
        if (!this.repo.categories || !this.repo.categories[key]) {
            return undefined;
        }
        return new model_1.Category(this.repo.categories[key], this);
    };
    Object.defineProperty(Repository.prototype, "hasCategories", {
        get: function () {
            return !!this.repo.categories;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "categories", {
        get: function () {
            var _this = this;
            if (!this.hasCategories) {
                return [];
            }
            return Object.values(this.repo.categories).map(function (c) { return new model_1.Category(c, _this); });
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.getCodeSet = function (key) {
        var result = this.repo.codeSets[key];
        if (!result) {
            return undefined;
        }
        return this.repo.codeSets[key];
    };
    Object.defineProperty(Repository.prototype, "codeSets", {
        get: function () {
            return Object.values(this.repo.codeSets);
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.getComponent = function (key) {
        if (!this.repo.components || !this.repo.components[key]) {
            return undefined;
        }
        return new model_1.Component(this.repo.components[key], this);
    };
    Object.defineProperty(Repository.prototype, "components", {
        get: function () {
            var _this = this;
            return Object.values(this.repo.components).map(function (c) { return new model_1.Component(c, _this); });
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.getDataType = function (key) {
        if (!this.repo.dataTypes[key]) {
            return {
                name: key
            };
        }
        return this.repo.dataTypes[key];
    };
    Object.defineProperty(Repository.prototype, "dataTypes", {
        get: function () {
            return Object.values(this.repo.dataTypes);
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.getSection = function (key) {
        if (!this.repo.sections || !this.repo.sections[key]) {
            return undefined;
        }
        return this.repo.sections[key];
    };
    Object.defineProperty(Repository.prototype, "sections", {
        get: function () {
            if (!this.repo.sections) {
                return [];
            }
            return Object.values(this.repo.sections);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Repository.prototype, "fields", {
        get: function () {
            var _this = this;
            return Object.values(this.repo.fields).map(function (field) { return new model_1.Field(field, _this); });
        },
        enumerable: true,
        configurable: true
    });
    Repository.prototype.getField = function (tag) {
        if (!this.repo.fields[tag]) {
            return undefined;
        }
        return new model_1.Field(this.repo.fields[tag], this);
    };
    Object.defineProperty(Repository.prototype, "messages", {
        get: function () {
            var _this = this;
            return Object.values(this.repo.messages).map(function (message) { return new model_1.Message(message, _this); });
        },
        enumerable: true,
        configurable: true
    });
    return Repository;
}());
exports.default = Repository;

//# sourceMappingURL=repository.js.map
